var group__spa__pod =
[
    [ "builder.h", "builder_8h.html", null ],
    [ "pod/command.h", "pod_2command_8h.html", null ],
    [ "compare.h", "compare_8h.html", null ],
    [ "pod/event.h", "pod_2event_8h.html", null ],
    [ "spa/include/spa/pod/filter.h", "spa_2include_2spa_2pod_2filter_8h.html", null ],
    [ "iter.h", "iter_8h.html", null ],
    [ "parser.h", "parser_8h.html", null ],
    [ "pod/pod.h", "pod_2pod_8h.html", null ],
    [ "vararg.h", "vararg_8h.html", null ],
    [ "spa_pod_builder_state", "structspa__pod__builder__state.html", [
      [ "offset", "structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae", null ],
      [ "flags", "structspa__pod__builder__state.html#a9406fb7fd6f0ea3cc9e99c9be6d76661", null ],
      [ "frame", "structspa__pod__builder__state.html#ad4d8cb79bdf194c752fc697eb7d63341", null ]
    ] ],
    [ "spa_pod_builder_callbacks", "structspa__pod__builder__callbacks.html", [
      [ "version", "structspa__pod__builder__callbacks.html#ad6d4638170f1441ba8c786ea174df911", null ],
      [ "overflow", "structspa__pod__builder__callbacks.html#a8acfb9e8c57e0c3ac2d3dac4a4f37aa6", null ]
    ] ],
    [ "spa_pod_builder", "structspa__pod__builder.html", [
      [ "data", "structspa__pod__builder.html#a4a8ea2b371e6be4e67bf6ce0b64c5ab2", null ],
      [ "size", "structspa__pod__builder.html#a9c1ccf4a2a2d89854665f96764835bbf", null ],
      [ "_padding", "structspa__pod__builder.html#a0cbaecf9bb1eaa9091928f88f52f1dec", null ],
      [ "state", "structspa__pod__builder.html#a701f8e524b951931ce8e390b96c75db9", null ],
      [ "callbacks", "structspa__pod__builder.html#a10358b3530a605742fbd6488ec1acffd", null ]
    ] ],
    [ "spa_command_body", "structspa__command__body.html", [
      [ "body", "structspa__command__body.html#ab477c03f242e4d10ed2a4e7057f52123", null ]
    ] ],
    [ "spa_command", "structspa__command.html", [
      [ "pod", "structspa__command.html#ad422c2065f2080f39a1ee42b77154c55", null ],
      [ "body", "structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e", null ]
    ] ],
    [ "spa_event_body", "structspa__event__body.html", [
      [ "body", "structspa__event__body.html#aa484bc2cadd16a104476183666de3819", null ]
    ] ],
    [ "spa_event", "structspa__event.html", [
      [ "pod", "structspa__event.html#a2411141eed88d3587687a8d86c99d488", null ],
      [ "body", "structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb", null ]
    ] ],
    [ "spa_pod_frame", "structspa__pod__frame.html", [
      [ "pod", "structspa__pod__frame.html#a33639010072a6ae1c60f0abb559d0197", null ],
      [ "parent", "structspa__pod__frame.html#a51486db1e9f9e886bc0b0858321f1252", null ],
      [ "offset", "structspa__pod__frame.html#a3af1eba573563e63ed9d5fa9b3246795", null ],
      [ "flags", "structspa__pod__frame.html#aedaebc9933fd5e625c622c3a0f1f2d64", null ]
    ] ],
    [ "spa_pod_parser_state", "structspa__pod__parser__state.html", [
      [ "offset", "structspa__pod__parser__state.html#a7d20db21de9472df961d8b2da5845ea0", null ],
      [ "flags", "structspa__pod__parser__state.html#a88566be69781e492f2927a83429d0d28", null ],
      [ "frame", "structspa__pod__parser__state.html#acf6a430c72bd19259ecbda4643d4b2cf", null ]
    ] ],
    [ "spa_pod_parser", "structspa__pod__parser.html", [
      [ "data", "structspa__pod__parser.html#a4573bb26e3ca5a5df90101715117ddb4", null ],
      [ "size", "structspa__pod__parser.html#a063ba699d1129ec01a15af8623d83441", null ],
      [ "_padding", "structspa__pod__parser.html#aa910ae08071e719f1eb318c5fd772fb3", null ],
      [ "state", "structspa__pod__parser.html#a133bcad805d3b0cbb5cf531af5bf2df8", null ]
    ] ],
    [ "spa_pod", "structspa__pod.html", [
      [ "size", "structspa__pod.html#ad7c483f4a522ca9bf9703f7d5baf1398", null ],
      [ "type", "structspa__pod.html#a3f7077ea0a9d9fedac8b7ba74cb23408", null ]
    ] ],
    [ "spa_pod_bool", "structspa__pod__bool.html", [
      [ "pod", "structspa__pod__bool.html#ace69d7dd77f754dc466e24e0598b865c", null ],
      [ "value", "structspa__pod__bool.html#aa9db4ceb398b4e0b3ffba65b08c38c4d", null ],
      [ "_padding", "structspa__pod__bool.html#a0813dfc89b4ac463bbbe527dd64723a0", null ]
    ] ],
    [ "spa_pod_id", "structspa__pod__id.html", [
      [ "pod", "structspa__pod__id.html#af8623276726ff78da3bc0f7a8c0bba1b", null ],
      [ "value", "structspa__pod__id.html#a6313b9440a92ad53fa8cdd7a2902b817", null ],
      [ "_padding", "structspa__pod__id.html#aa884f5dc42c8a5e8ec17d2a3a66be2ea", null ]
    ] ],
    [ "spa_pod_int", "structspa__pod__int.html", [
      [ "pod", "structspa__pod__int.html#a68d3e9d0f9aff4aa84a907a9d8ff07c8", null ],
      [ "value", "structspa__pod__int.html#ab0f590008a307cc732cba65d45b62299", null ],
      [ "_padding", "structspa__pod__int.html#a74ea15dcbf22eddbe16372ad50392ed3", null ]
    ] ],
    [ "spa_pod_long", "structspa__pod__long.html", [
      [ "pod", "structspa__pod__long.html#a8b04bfc3d7876362001efa4f3585f186", null ],
      [ "value", "structspa__pod__long.html#a6a21d96d55e7dcbb392d1058411ec861", null ]
    ] ],
    [ "spa_pod_float", "structspa__pod__float.html", [
      [ "pod", "structspa__pod__float.html#a858e59d880b7e0cd076a0c178a576894", null ],
      [ "value", "structspa__pod__float.html#af197d9ca01cc60ca6280e0c0a18a2c90", null ],
      [ "_padding", "structspa__pod__float.html#a84f5624baada7889f840a015eb2ef6c7", null ]
    ] ],
    [ "spa_pod_double", "structspa__pod__double.html", [
      [ "pod", "structspa__pod__double.html#ade75ab6437b765fba0c53bb395271a3e", null ],
      [ "value", "structspa__pod__double.html#a3cd088027c7a855edf33339909b0207a", null ]
    ] ],
    [ "spa_pod_string", "structspa__pod__string.html", [
      [ "pod", "structspa__pod__string.html#aa7b8596a64741c1f0b728bc066643c79", null ]
    ] ],
    [ "spa_pod_bytes", "structspa__pod__bytes.html", [
      [ "pod", "structspa__pod__bytes.html#acf53b79878e4a426d95574190055b5e8", null ]
    ] ],
    [ "spa_pod_rectangle", "structspa__pod__rectangle.html", [
      [ "pod", "structspa__pod__rectangle.html#a03b8318f1784bbd03fad4b7187b18c9e", null ],
      [ "value", "structspa__pod__rectangle.html#a3599080e445b31f812cc4563be10c2ed", null ]
    ] ],
    [ "spa_pod_fraction", "structspa__pod__fraction.html", [
      [ "pod", "structspa__pod__fraction.html#ad56b6e9e60a4757fb1b78f86c2604eba", null ],
      [ "value", "structspa__pod__fraction.html#ad4721083814a2b28b47ba639cc0c40a6", null ]
    ] ],
    [ "spa_pod_bitmap", "structspa__pod__bitmap.html", [
      [ "pod", "structspa__pod__bitmap.html#ad45678422944ed0fd6a3b82b976497dc", null ]
    ] ],
    [ "spa_pod_array_body", "structspa__pod__array__body.html", [
      [ "child", "structspa__pod__array__body.html#a3822d2dc2ac7c37b2a90b91daab8d271", null ]
    ] ],
    [ "spa_pod_array", "structspa__pod__array.html", [
      [ "pod", "structspa__pod__array.html#a012fbf2f9cdca9b6bbd07c9a027a5a98", null ],
      [ "body", "structspa__pod__array.html#a30a4ff74b448da3df862a7bdb20dad04", null ]
    ] ],
    [ "spa_pod_choice_body", "structspa__pod__choice__body.html", [
      [ "type", "structspa__pod__choice__body.html#a24335975777563cb1c8be5df46ed8aca", null ],
      [ "flags", "structspa__pod__choice__body.html#aa81807e624ebb3832d6fcb0e2a88cb11", null ],
      [ "child", "structspa__pod__choice__body.html#a20700829b69701c8243986c02a5eeb67", null ]
    ] ],
    [ "spa_pod_choice", "structspa__pod__choice.html", [
      [ "pod", "structspa__pod__choice.html#af1123be5c1dd70873b8d9ff4ea1ad8ed", null ],
      [ "body", "structspa__pod__choice.html#aa9927ee9a4a320384560480e1783705c", null ]
    ] ],
    [ "spa_pod_struct", "structspa__pod__struct.html", [
      [ "pod", "structspa__pod__struct.html#a60dbfcf74d9a0dca707123f887817030", null ]
    ] ],
    [ "spa_pod_object_body", "structspa__pod__object__body.html", [
      [ "type", "structspa__pod__object__body.html#a9f69ed05dcb33536cb39a861631056a8", null ],
      [ "id", "structspa__pod__object__body.html#aae0deac8b4710eb26e5fc711896aac25", null ]
    ] ],
    [ "spa_pod_object", "structspa__pod__object.html", [
      [ "pod", "structspa__pod__object.html#a48beaa7536f4c339aac23729c42a64f3", null ],
      [ "body", "structspa__pod__object.html#a5432f079d6ffcb0d2f0baee8a130219a", null ]
    ] ],
    [ "spa_pod_pointer_body", "structspa__pod__pointer__body.html", [
      [ "type", "structspa__pod__pointer__body.html#afb961dfc1e63a4ec811af33c4183ecaa", null ],
      [ "_padding", "structspa__pod__pointer__body.html#a2c444fd3eda0725199a91713c7b5676c", null ],
      [ "value", "structspa__pod__pointer__body.html#a2b72ed680f7e85d988498503dc66df7e", null ]
    ] ],
    [ "spa_pod_pointer", "structspa__pod__pointer.html", [
      [ "pod", "structspa__pod__pointer.html#a1aefb7792b75ea7882c273abf8a2edce", null ],
      [ "body", "structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7", null ]
    ] ],
    [ "spa_pod_fd", "structspa__pod__fd.html", [
      [ "pod", "structspa__pod__fd.html#a30053416214092ba7fb4f8411c4ab3a1", null ],
      [ "value", "structspa__pod__fd.html#a1158a743a7aace37f7490d426bb72c92", null ]
    ] ],
    [ "spa_pod_prop", "structspa__pod__prop.html", [
      [ "key", "structspa__pod__prop.html#a1d32ef4e73f00e16b07a0cecd3f18fe0", null ],
      [ "flags", "structspa__pod__prop.html#a5f3d78759992c01a760d12743446e8b6", null ],
      [ "value", "structspa__pod__prop.html#aa5b6f5944e22f135b02594cc173799bb", null ]
    ] ],
    [ "spa_pod_control", "structspa__pod__control.html", [
      [ "offset", "structspa__pod__control.html#ae2a97b90cef2051c5bc8fa6db940179d", null ],
      [ "type", "structspa__pod__control.html#adeb12535d89c6cfd05a27edf7c981e4e", null ],
      [ "value", "structspa__pod__control.html#ab3d78b052b6fbcba7e2d0f543e7c4dac", null ]
    ] ],
    [ "spa_pod_sequence_body", "structspa__pod__sequence__body.html", [
      [ "unit", "structspa__pod__sequence__body.html#ae83a44c4123cc5dc4450a985d4c4445d", null ],
      [ "pad", "structspa__pod__sequence__body.html#adcbb3a7881352555c1a9340662f25c77", null ]
    ] ],
    [ "spa_pod_sequence", "structspa__pod__sequence.html", [
      [ "pod", "structspa__pod__sequence.html#abaef5cba65ad23552570ff78c550838f", null ],
      [ "body", "structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163", null ]
    ] ],
    [ "SPA_POD_BUILDER_FLAG_BODY", "group__spa__pod.html#ga3b0caae7fd8281ebc926bbac640c4f5f", null ],
    [ "SPA_POD_BUILDER_FLAG_FIRST", "group__spa__pod.html#gadc6048dc20a1aa0eb2b4f578b8e63288", null ],
    [ "SPA_VERSION_POD_BUILDER_CALLBACKS", "group__spa__pod.html#gadfbece2397bade8f3802ac60b6dcaea7", null ],
    [ "SPA_POD_BUILDER_INIT", "group__spa__pod.html#ga6539c8d845251a865cc220fde122c94f", null ],
    [ "SPA_POD_INIT", "group__spa__pod.html#ga180658647f310f028703746d7f383ae0", null ],
    [ "SPA_POD_INIT_None", "group__spa__pod.html#ga0c8f9f1df38d704f80b45f1750165a1e", null ],
    [ "SPA_POD_INIT_Bool", "group__spa__pod.html#ga4c35e58037a9afea52cb6697bb890eba", null ],
    [ "SPA_POD_INIT_Id", "group__spa__pod.html#ga59e6ab3216ad9c773e8f9bb018d91005", null ],
    [ "SPA_POD_INIT_Int", "group__spa__pod.html#gab49ed36f15b44b11c67d6c1d21392fcc", null ],
    [ "SPA_POD_INIT_Long", "group__spa__pod.html#gad1be859cbe04d434860019552cc31f03", null ],
    [ "SPA_POD_INIT_Float", "group__spa__pod.html#gabc8a77a767e20163e368ed09ab01f527", null ],
    [ "SPA_POD_INIT_Double", "group__spa__pod.html#ga00fbe47e3b885d1c8499f321f3f941d3", null ],
    [ "SPA_POD_INIT_String", "group__spa__pod.html#ga4f092eabdbcc9883ce781d1bc76544f8", null ],
    [ "SPA_POD_INIT_Bytes", "group__spa__pod.html#gabfbc756b591101e1521baca4ac836d17", null ],
    [ "SPA_POD_INIT_Pointer", "group__spa__pod.html#gad36c51fc8272b39d00103a2afde4873b", null ],
    [ "SPA_POD_INIT_Fd", "group__spa__pod.html#gabfd7cabf02c9c9799dd3849d67e23e96", null ],
    [ "SPA_POD_INIT_Rectangle", "group__spa__pod.html#ga4585068580d727cb9c39ab0387069819", null ],
    [ "SPA_POD_INIT_Fraction", "group__spa__pod.html#gad9339d4e5ef6a813a02a1c6f36994205", null ],
    [ "SPA_POD_INIT_CHOICE_BODY", "group__spa__pod.html#gac022dd90e1825a278defc28fc33ce2ba", null ],
    [ "SPA_POD_INIT_Choice", "group__spa__pod.html#ga5851918fa5fa06d10975e4d3b7bca465", null ],
    [ "SPA_POD_INIT_Struct", "group__spa__pod.html#ga7068d1d17595406018d7739221256cce", null ],
    [ "SPA_POD_INIT_Object", "group__spa__pod.html#ga31bf2d7eb1f059ab63a42c98b3471c8c", null ],
    [ "SPA_POD_INIT_Prop", "group__spa__pod.html#gad33703d22304b4f1cc2477ed8065f10a", null ],
    [ "SPA_POD_INIT_Sequence", "group__spa__pod.html#ga45273855ab74c08881722327dece0d2d", null ],
    [ "SPA_POD_BUILDER_COLLECT", "group__spa__pod.html#ga966c1970fd507d5d18fc1c8d698c9188", null ],
    [ "spa_pod_builder_add_object", "group__spa__pod.html#ga9fe01860039f5c200cb8bc216e746f87", null ],
    [ "spa_pod_builder_add_struct", "group__spa__pod.html#ga01e98602fd16231cf7a0e35b548151b9", null ],
    [ "spa_pod_builder_add_sequence", "group__spa__pod.html#ga7f59bef75b6bc82839180380bf3c3dd5", null ],
    [ "SPA_COMMAND_TYPE", "group__spa__pod.html#gaff9715691ea5e8a6853cf7a25875d3ca", null ],
    [ "SPA_COMMAND_ID", "group__spa__pod.html#ga4af85c705eae32732d08dd70375e6720", null ],
    [ "SPA_COMMAND_INIT_FULL", "group__spa__pod.html#gaac19947b3951974ca80dcff4be99de9d", null ],
    [ "SPA_COMMAND_INIT", "group__spa__pod.html#ga2734f1390d46a1d07a30f2c50ce9f7c0", null ],
    [ "SPA_EVENT_TYPE", "group__spa__pod.html#ga7c95b0ed12cb9e712b64568144c8edd6", null ],
    [ "SPA_EVENT_ID", "group__spa__pod.html#gadc95294cb92f459ba47fcf47234d956e", null ],
    [ "SPA_EVENT_INIT_FULL", "group__spa__pod.html#gac43246ee52a55c4c43ee8c144f31a387", null ],
    [ "SPA_EVENT_INIT", "group__spa__pod.html#ga1a3d96d89c61282fecd559166353f20a", null ],
    [ "SPA_POD_ARRAY_BODY_FOREACH", "group__spa__pod.html#gad7ead1f611932f6b96fafcf483e86799", null ],
    [ "SPA_POD_ARRAY_FOREACH", "group__spa__pod.html#ga07d499eaee993c61b08998ed20843c81", null ],
    [ "SPA_POD_CHOICE_BODY_FOREACH", "group__spa__pod.html#ga1d4549904c233c319e9a6222d7781948", null ],
    [ "SPA_POD_CHOICE_FOREACH", "group__spa__pod.html#gabe3950ff8e04081058831dfab60c0eba", null ],
    [ "SPA_POD_FOREACH", "group__spa__pod.html#ga90c2f3404cba18be412baf930d159344", null ],
    [ "SPA_POD_STRUCT_FOREACH", "group__spa__pod.html#ga9d02cb79ce7971d17ffaf7875b1abfc7", null ],
    [ "SPA_POD_OBJECT_BODY_FOREACH", "group__spa__pod.html#ga03369b7d4c58b34a24a00bb9ea8b96a7", null ],
    [ "SPA_POD_OBJECT_FOREACH", "group__spa__pod.html#ga506778bb5f4ce87c3416461951633777", null ],
    [ "SPA_POD_SEQUENCE_BODY_FOREACH", "group__spa__pod.html#ga978ad0926ea7b81d8f4e9ebf4208a037", null ],
    [ "SPA_POD_SEQUENCE_FOREACH", "group__spa__pod.html#gafb8085004dbaedb99b30642a18565425", null ],
    [ "SPA_POD_PARSER_INIT", "group__spa__pod.html#gab0090b49be0a521de62ac22c01096583", null ],
    [ "SPA_POD_PARSER_COLLECT", "group__spa__pod.html#ga79289217b54e0fd108361a43ad6908e8", null ],
    [ "SPA_POD_PARSER_SKIP", "group__spa__pod.html#ga8ef478dc6a1a7ceada9406226d72ce8e", null ],
    [ "SPA_POD_OPT_Bool", "group__spa__pod.html#ga9b47be17366e2b3d3f6c312ba29e6fc7", null ],
    [ "SPA_POD_OPT_Id", "group__spa__pod.html#gaae8107547cc28f6c5fd9b57cfac5ef61", null ],
    [ "SPA_POD_OPT_Int", "group__spa__pod.html#ga897e33e5093184c6876262677f0e38c4", null ],
    [ "SPA_POD_OPT_Long", "group__spa__pod.html#gae5bc1cb159df6384de08a687180e65c5", null ],
    [ "SPA_POD_OPT_Float", "group__spa__pod.html#ga0f34eabbc463506ce71870887334a05c", null ],
    [ "SPA_POD_OPT_Double", "group__spa__pod.html#ga556ccaadaffe6efff639761e18f154e4", null ],
    [ "SPA_POD_OPT_String", "group__spa__pod.html#gac0dc333665ae57f9630b06541e4eac1e", null ],
    [ "SPA_POD_OPT_Stringn", "group__spa__pod.html#ga72b8d07edeb4ac6664cfed38dab464f9", null ],
    [ "SPA_POD_OPT_Bytes", "group__spa__pod.html#gafb96d04250adb788262c02e4e91db3bd", null ],
    [ "SPA_POD_OPT_Rectangle", "group__spa__pod.html#ga1f3c199dee1fd8ccd8aa6a0426c4ede9", null ],
    [ "SPA_POD_OPT_Fraction", "group__spa__pod.html#ga5601a1f1af91fe01c9ddb3fe8323d824", null ],
    [ "SPA_POD_OPT_Array", "group__spa__pod.html#gabeb9f4ba613e100a0f399c8d2a3846aa", null ],
    [ "SPA_POD_OPT_Pointer", "group__spa__pod.html#ga86b759c508891cf57a9c1d2a5690a20f", null ],
    [ "SPA_POD_OPT_Fd", "group__spa__pod.html#ga8c70fe74b4ef8628e54a45c238b221ea", null ],
    [ "SPA_POD_OPT_Pod", "group__spa__pod.html#gac1f8a1316661714e692b157d43cd9163", null ],
    [ "SPA_POD_OPT_PodObject", "group__spa__pod.html#ga0fd9ec3343da98a5c2a560d178dbcac1", null ],
    [ "SPA_POD_OPT_PodStruct", "group__spa__pod.html#ga2d61a450e8328ebca28a7ac49850840f", null ],
    [ "SPA_POD_OPT_PodChoice", "group__spa__pod.html#ga1959af59211475212f6e922f292cab02", null ],
    [ "spa_pod_parser_get_object", "group__spa__pod.html#gac7107618cd0900307bee56d083ff8d91", null ],
    [ "spa_pod_parser_get_struct", "group__spa__pod.html#ga8789019e53e045798845b3c4057ad304", null ],
    [ "spa_pod_parse_object", "group__spa__pod.html#gad661885d5748dcaaaa1b7b8ace57697f", null ],
    [ "spa_pod_parse_struct", "group__spa__pod.html#gafadfef9f3f4a5295d253339b2b54a3c2", null ],
    [ "SPA_POD_BODY_SIZE", "group__spa__pod.html#ga641b2447836ae0dd32a1d8eeb19d611b", null ],
    [ "SPA_POD_TYPE", "group__spa__pod.html#ga555bfc9f09222a6586ad8871378bfbce", null ],
    [ "SPA_POD_SIZE", "group__spa__pod.html#gae7c656416f904f94caf9d4a74f9971eb", null ],
    [ "SPA_POD_CONTENTS_SIZE", "group__spa__pod.html#ga7dcee1f3ff7993a0b3f80c224977d1f4", null ],
    [ "SPA_POD_CONTENTS", "group__spa__pod.html#ga954f830c617485ff7d821aee571d9a09", null ],
    [ "SPA_POD_CONTENTS_CONST", "group__spa__pod.html#ga0588f94569fca38df6c721191b666680", null ],
    [ "SPA_POD_BODY", "group__spa__pod.html#ga5081fb36182775a5c843682e0210d2dc", null ],
    [ "SPA_POD_BODY_CONST", "group__spa__pod.html#ga26c770ca09d2170be9f8fe2725901e03", null ],
    [ "SPA_POD_VALUE", "group__spa__pod.html#ga360a550f22f66ade502d7662eca14767", null ],
    [ "SPA_POD_ARRAY_CHILD", "group__spa__pod.html#gaa2542f359436bc2d864ddfdd211f77d7", null ],
    [ "SPA_POD_ARRAY_VALUE_TYPE", "group__spa__pod.html#gabb9e7a368ef87910abc4a0856afe0087", null ],
    [ "SPA_POD_ARRAY_VALUE_SIZE", "group__spa__pod.html#ga8d50cace22dbffe2630623fc5ee00b21", null ],
    [ "SPA_POD_ARRAY_N_VALUES", "group__spa__pod.html#gaf29f98cbf0355c53cb8ad12919c28b14", null ],
    [ "SPA_POD_ARRAY_VALUES", "group__spa__pod.html#gafaea466349f7c1b84793d122d1b595b3", null ],
    [ "SPA_POD_CHOICE_CHILD", "group__spa__pod.html#gaee78fa7defd3ae562502ee1c46b673c9", null ],
    [ "SPA_POD_CHOICE_TYPE", "group__spa__pod.html#gaf33e1e0f54d32192f1595d98a7004d4d", null ],
    [ "SPA_POD_CHOICE_FLAGS", "group__spa__pod.html#ga3f71fd97eb4ca17b150a34bf05272307", null ],
    [ "SPA_POD_CHOICE_VALUE_TYPE", "group__spa__pod.html#ga18d0e2e837c95fd3d896f8cb6d674844", null ],
    [ "SPA_POD_CHOICE_VALUE_SIZE", "group__spa__pod.html#ga438a8d9d55d42623cf9bf7f1d2a9fdfd", null ],
    [ "SPA_POD_CHOICE_N_VALUES", "group__spa__pod.html#gac9ea5c51626d23ced5b6da1915dde2e8", null ],
    [ "SPA_POD_CHOICE_VALUES", "group__spa__pod.html#ga9eaa0e37a9158469e2cef7aa5f04b04d", null ],
    [ "SPA_POD_OBJECT_TYPE", "group__spa__pod.html#gab9cf2b5574f4fe4390911f514229b3ee", null ],
    [ "SPA_POD_OBJECT_ID", "group__spa__pod.html#gab9d3422b05af657d6370a6ad789c05a9", null ],
    [ "SPA_POD_PROP_SIZE", "group__spa__pod.html#ga9f6c324e82fc04180ea7d70ce1f8347a", null ],
    [ "SPA_POD_PROP_FLAG_READONLY", "group__spa__pod.html#ga2890e7200bc48f0b0cfbb4073957d374", null ],
    [ "SPA_POD_PROP_FLAG_HARDWARE", "group__spa__pod.html#gae46ad1fd3f194bcdf60bab73133a64d1", null ],
    [ "SPA_POD_PROP_FLAG_HINT_DICT", "group__spa__pod.html#gacc252920ec203fb6a49e82ccb4f80edd", null ],
    [ "SPA_POD_PROP_FLAG_MANDATORY", "group__spa__pod.html#ga3710deebd2fedd9eaf9f9f5e73a3ac01", null ],
    [ "SPA_POD_PROP_FLAG_DONT_FIXATE", "group__spa__pod.html#ga765ef8a7efa487db110ec67c998ff2ea", null ],
    [ "SPA_POD_CONTROL_SIZE", "group__spa__pod.html#ga9189a4c2f9bf8f7022e6f98c9b24ebfe", null ],
    [ "SPA_POD_Prop", "group__spa__pod.html#ga889dbb7e4f3b0ff6f885d26398e87c4c", null ],
    [ "SPA_POD_Control", "group__spa__pod.html#ga2313f26833e446d185bdb0600a45fb8f", null ],
    [ "SPA_CHOICE_RANGE", "group__spa__pod.html#ga144704206888a0e6405790fd694fa296", null ],
    [ "SPA_CHOICE_STEP", "group__spa__pod.html#ga92ea46020be2f82c651369d76c9e137a", null ],
    [ "SPA_CHOICE_ENUM", "group__spa__pod.html#gadd96b34a074f0a4065ae1e3d055ef99f", null ],
    [ "SPA_CHOICE_FLAGS", "group__spa__pod.html#ga26823c0f7c08a7b361451575493c6c9c", null ],
    [ "SPA_CHOICE_BOOL", "group__spa__pod.html#ga80c22ac336bb35f14a3692372f13c01f", null ],
    [ "SPA_POD_Bool", "group__spa__pod.html#ga10cb92b7996b3ed2b31295fc52bb83f9", null ],
    [ "SPA_POD_CHOICE_Bool", "group__spa__pod.html#ga77acabfebad965007133387bed64922d", null ],
    [ "SPA_POD_Id", "group__spa__pod.html#ga64526ff3bab813a3d2d85549c14bbfd9", null ],
    [ "SPA_POD_CHOICE_ENUM_Id", "group__spa__pod.html#ga263e5559ecd6624a92ba2edefc3277cc", null ],
    [ "SPA_POD_Int", "group__spa__pod.html#gad87eb5569b20e96ec92f152b013487af", null ],
    [ "SPA_POD_CHOICE_ENUM_Int", "group__spa__pod.html#ga61c8ca01ec5d0579f24b1351030d0b1e", null ],
    [ "SPA_POD_CHOICE_RANGE_Int", "group__spa__pod.html#ga57b2b5bc72e7fbf6c78cfd5d601ad855", null ],
    [ "SPA_POD_CHOICE_STEP_Int", "group__spa__pod.html#ga6432e0723995e1dec2b9ae6b76a6bd91", null ],
    [ "SPA_POD_CHOICE_FLAGS_Int", "group__spa__pod.html#gaea71c973cc38a58e1efd3ab257278d72", null ],
    [ "SPA_POD_Long", "group__spa__pod.html#ga2fb7171ab4bf8b85b835c8ac66cc3a26", null ],
    [ "SPA_POD_CHOICE_ENUM_Long", "group__spa__pod.html#ga7a44d36fbdc823dc9befeccad3429635", null ],
    [ "SPA_POD_CHOICE_RANGE_Long", "group__spa__pod.html#ga00e180f5c166a1ab73d13357244e5eef", null ],
    [ "SPA_POD_CHOICE_STEP_Long", "group__spa__pod.html#ga95b23f18f2136eee0eb6e9c8446caa7a", null ],
    [ "SPA_POD_CHOICE_FLAGS_Long", "group__spa__pod.html#ga13bd8184344389ed4e4007872286ae81", null ],
    [ "SPA_POD_Float", "group__spa__pod.html#gaa5ae3c08bb5f3e90e5b0688c5668e002", null ],
    [ "SPA_POD_CHOICE_ENUM_Float", "group__spa__pod.html#ga697129f8c015770ec03468adf9127705", null ],
    [ "SPA_POD_CHOICE_RANGE_Float", "group__spa__pod.html#ga0f55c34f22f68b723fca4a416841b247", null ],
    [ "SPA_POD_CHOICE_STEP_Float", "group__spa__pod.html#gaae49a58ec3086fdec3b06b8093746efb", null ],
    [ "SPA_POD_Double", "group__spa__pod.html#ga1a697b19704efa77dc667a417c8d8686", null ],
    [ "SPA_POD_CHOICE_ENUM_Double", "group__spa__pod.html#gaec0349577bbf76820712010daaeff6b7", null ],
    [ "SPA_POD_CHOICE_RANGE_Double", "group__spa__pod.html#ga04aa72492dea8a0df43ac4f2c24a0d99", null ],
    [ "SPA_POD_CHOICE_STEP_Double", "group__spa__pod.html#gac38f2af1115887f1fcbdcbb943947d04", null ],
    [ "SPA_POD_String", "group__spa__pod.html#ga10af538f466cc709f3d6ed609cd4b461", null ],
    [ "SPA_POD_Stringn", "group__spa__pod.html#ga6e721c63439ae54ab8e462e5f73f3e94", null ],
    [ "SPA_POD_Bytes", "group__spa__pod.html#ga02ac2eca2d7a3ae9b6c9f47ed45e9e82", null ],
    [ "SPA_POD_Rectangle", "group__spa__pod.html#gabf8784a13feb54e7383c640410f33b1c", null ],
    [ "SPA_POD_CHOICE_ENUM_Rectangle", "group__spa__pod.html#ga04d11c1b86d19003de5bd77ee9bfbf64", null ],
    [ "SPA_POD_CHOICE_RANGE_Rectangle", "group__spa__pod.html#ga6d9697c9611884f446b8e22a787fa3b2", null ],
    [ "SPA_POD_CHOICE_STEP_Rectangle", "group__spa__pod.html#ga027b602b893d7d92c00e1ce240a0dda8", null ],
    [ "SPA_POD_Fraction", "group__spa__pod.html#ga0c975a1edbf332b74d39aa7cd8daa10b", null ],
    [ "SPA_POD_CHOICE_ENUM_Fraction", "group__spa__pod.html#ga51737fd8d2c8ddcb95e883865e6b0ee7", null ],
    [ "SPA_POD_CHOICE_RANGE_Fraction", "group__spa__pod.html#ga335d01dbea6109b55ea0fe4e5867336c", null ],
    [ "SPA_POD_CHOICE_STEP_Fraction", "group__spa__pod.html#gaf31ee2bff0720fa43b2d69dd88f149a3", null ],
    [ "SPA_POD_Array", "group__spa__pod.html#ga3882f37f9dcec8442a669f4b38631caa", null ],
    [ "SPA_POD_Pointer", "group__spa__pod.html#ga21a8fe02849dd7645721d6127300031c", null ],
    [ "SPA_POD_Fd", "group__spa__pod.html#ga92cfddc1b1b7a51ee7c4e4f25e3525d6", null ],
    [ "SPA_POD_None", "group__spa__pod.html#gae456fc1be7b6e362a02af36f33344db3", null ],
    [ "SPA_POD_Pod", "group__spa__pod.html#gadfde26bef2b16e0d1fd3a7dfc0780943", null ],
    [ "SPA_POD_PodObject", "group__spa__pod.html#gaa0db41ba0cc387086b23f9d1cf743b93", null ],
    [ "SPA_POD_PodStruct", "group__spa__pod.html#gae0e9d191c91c8a70852a875dda2a06b6", null ],
    [ "SPA_POD_PodChoice", "group__spa__pod.html#ga6acb5a42673d597a7a03f2c2a056e053", null ],
    [ "spa_choice_type", "group__spa__pod.html#ga38ee9b093a1a766cfc3d96db7c28067f", [
      [ "SPA_CHOICE_None", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fa32b771a9215a8b824a90e0ffe30e6e06", null ],
      [ "SPA_CHOICE_Range", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fab83a47468dd6f92b64b943c4974cf799", null ],
      [ "SPA_CHOICE_Step", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fa1e4c2c416f1964603dbbf4ff58dab22e", null ],
      [ "SPA_CHOICE_Enum", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067faf6fab992aeab2da08ea1ff556272ce5f", null ],
      [ "SPA_CHOICE_Flags", "group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fa82fbd414410e306dc9e4cf3a2ac4dc78", null ]
    ] ],
    [ "spa_pod_builder_get_state", "group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec", null ],
    [ "spa_pod_builder_set_callbacks", "group__spa__pod.html#ga4af1361c985badef6492259d57a50313", null ],
    [ "spa_pod_builder_reset", "group__spa__pod.html#ga51ce89d586f0ebe8b636905fdbd50017", null ],
    [ "spa_pod_builder_init", "group__spa__pod.html#gab989a0cb71f9cd64a9e9e55bdddc8b7b", null ],
    [ "spa_pod_builder_deref", "group__spa__pod.html#gaf08245bcd5bb244e6ea3d7520b4a665c", null ],
    [ "spa_pod_builder_frame", "group__spa__pod.html#ga513238371ee54a3ef16170f0e0837361", null ],
    [ "spa_pod_builder_push", "group__spa__pod.html#ga3bd72e84bf9817f0fcc58bc45afe0bfd", null ],
    [ "spa_pod_builder_raw", "group__spa__pod.html#gab1e994f1dbe8353d46988c092f87ba37", null ],
    [ "spa_pod_builder_pad", "group__spa__pod.html#ga6b1922c10ef786d66c9a2177ff10137a", null ],
    [ "spa_pod_builder_raw_padded", "group__spa__pod.html#ga61c88157df991f9ae54bbdc174e75e7f", null ],
    [ "spa_pod_builder_pop", "group__spa__pod.html#ga6ad94cfd9e2816a83763788f032546ae", null ],
    [ "spa_pod_builder_primitive", "group__spa__pod.html#ga7a84af2ae6a8375b73f29337f32c744a", null ],
    [ "spa_pod_builder_none", "group__spa__pod.html#ga58eb1d962b1496daa88023eaf54cce30", null ],
    [ "spa_pod_builder_child", "group__spa__pod.html#ga204d1a47391802a5c04f2def9bbe919a", null ],
    [ "spa_pod_builder_bool", "group__spa__pod.html#ga929573f096e90d4aa11d14e1527d2d63", null ],
    [ "spa_pod_builder_id", "group__spa__pod.html#ga4e6318d6126ba71bbee8f9abe373705c", null ],
    [ "spa_pod_builder_int", "group__spa__pod.html#gab966fee940439f061d88b19064b8b5dd", null ],
    [ "spa_pod_builder_long", "group__spa__pod.html#gabeeecc8300aa1f563171db73c654b4d0", null ],
    [ "spa_pod_builder_float", "group__spa__pod.html#ga248c1c43ff4e5eb06f40b158e4a0118c", null ],
    [ "spa_pod_builder_double", "group__spa__pod.html#ga4059b7055950c4100924cf9bc2b4e23f", null ],
    [ "spa_pod_builder_write_string", "group__spa__pod.html#ga43f673bf5cd77a1a51e272d289c5e9f1", null ],
    [ "spa_pod_builder_string_len", "group__spa__pod.html#ga6e5334f69fcdb30c819cc2d2042cea4f", null ],
    [ "spa_pod_builder_string", "group__spa__pod.html#ga1dd09e366646a57e7ff74b2ca56c5e82", null ],
    [ "spa_pod_builder_bytes", "group__spa__pod.html#gab76a5f13f125ca2610906f28e1961b3c", null ],
    [ "spa_pod_builder_reserve_bytes", "group__spa__pod.html#ga015f21e522057422afcdc3933ae558d2", null ],
    [ "spa_pod_builder_pointer", "group__spa__pod.html#gaf7da1e4f789a92436cf3bc9c95469ca5", null ],
    [ "spa_pod_builder_fd", "group__spa__pod.html#ga500437e7eb44b8c952651347fb6c9af9", null ],
    [ "spa_pod_builder_rectangle", "group__spa__pod.html#ga21fc64d33bd3695de8dcf1f6f93317ca", null ],
    [ "spa_pod_builder_fraction", "group__spa__pod.html#ga2077f14c98a8f7061f98099922b7d908", null ],
    [ "spa_pod_builder_push_array", "group__spa__pod.html#ga7820560083401bab79329a6b3b138c7d", null ],
    [ "spa_pod_builder_array", "group__spa__pod.html#gac3d904dbfc22fc35a405e4f2b116f79e", null ],
    [ "spa_pod_builder_push_choice", "group__spa__pod.html#gab7706385d4c4463bdd28a1885135c3c2", null ],
    [ "spa_pod_builder_push_struct", "group__spa__pod.html#ga7d41061d62cfb1d25b3d35e35c3566ed", null ],
    [ "spa_pod_builder_push_object", "group__spa__pod.html#gab99db8b4a691fb02158e43a6eac39d96", null ],
    [ "spa_pod_builder_prop", "group__spa__pod.html#ga08615272e6e8633377ecdd5d22aec287", null ],
    [ "spa_pod_builder_push_sequence", "group__spa__pod.html#ga5f0935793f667923844cab08ea6f8637", null ],
    [ "spa_pod_builder_control", "group__spa__pod.html#ga7e2695ed7013bdf6791e692e3c726452", null ],
    [ "spa_choice_from_id", "group__spa__pod.html#ga7b7954e6302929958069d1eed005ab9b", null ],
    [ "spa_pod_builder_addv", "group__spa__pod.html#gaef57db1bd9e4683c0e96dd2d8e4dfc0c", null ],
    [ "spa_pod_builder_add", "group__spa__pod.html#ga4ed91d7bcbccedf0f26dbd3f563f900b", null ],
    [ "spa_pod_copy", "group__spa__pod.html#gaaf15f086fee08d6cd039b2524177e9b7", null ],
    [ "spa_pod_compare_value", "group__spa__pod.html#ga31a284dcca49f4fcd6f67982b51afacf", null ],
    [ "spa_pod_compare", "group__spa__pod.html#ga887a4f837a5690cc40fe30c8f4461452", null ],
    [ "spa_pod_choice_fix_default", "group__spa__pod.html#ga5e8d9e3e7fbbeff37cb0279160ca0962", null ],
    [ "spa_pod_filter_flags_value", "group__spa__pod.html#ga1a7880f8a28a30720da6bb6b636a9a1c", null ],
    [ "spa_pod_filter_is_step_of", "group__spa__pod.html#ga37b7c8a0ca1e4adafd4670340328d125", null ],
    [ "spa_pod_filter_prop", "group__spa__pod.html#ga67f021221aaedced51ab95dd8e7ef895", null ],
    [ "spa_pod_filter_part", "group__spa__pod.html#ga5d676b81bf66a4147c0f52d8ebdd5b5c", null ],
    [ "spa_pod_filter", "group__spa__pod.html#gaf40f681348bff742f24935a2075ef3bb", null ],
    [ "spa_pod_is_inside", "group__spa__pod.html#ga7c1572b9aa18a527d1e3e170fa5dbff9", null ],
    [ "spa_pod_next", "group__spa__pod.html#ga44d25c0de11b0d4b7e5a233aa944d54c", null ],
    [ "spa_pod_prop_first", "group__spa__pod.html#gacc743b22b0107a1b0f4311539ca395a6", null ],
    [ "spa_pod_prop_is_inside", "group__spa__pod.html#gaff752dbb4e7a42857fac48cba26a5e71", null ],
    [ "spa_pod_prop_next", "group__spa__pod.html#gab54ebaf45ffc4ff7e9cf126bdf215e58", null ],
    [ "spa_pod_control_first", "group__spa__pod.html#gac6e12a691e34645fedf6bf56dc36fe75", null ],
    [ "spa_pod_control_is_inside", "group__spa__pod.html#ga2b2f9467266bb48fb9f6ef72172ad529", null ],
    [ "spa_pod_control_next", "group__spa__pod.html#ga6af158c8b9440c5c5f9b0bbb7cf36625", null ],
    [ "spa_pod_from_data", "group__spa__pod.html#ga968fa8752e502888664b6a43b00287f0", null ],
    [ "spa_pod_is_none", "group__spa__pod.html#gade73b5e7c074fac279c18a325d894a71", null ],
    [ "spa_pod_is_bool", "group__spa__pod.html#gafdfd0a7b261b3fc146b9820eeb4bb729", null ],
    [ "spa_pod_get_bool", "group__spa__pod.html#gab0b7a7f005a8df9b0ca134294925cdca", null ],
    [ "spa_pod_is_id", "group__spa__pod.html#gac0b2f882008fa0493e6baf8283de6289", null ],
    [ "spa_pod_get_id", "group__spa__pod.html#ga5cac6d93f665bb39f005ed94a3b253e9", null ],
    [ "spa_pod_is_int", "group__spa__pod.html#gacd6d3f0ac979a45184017b64e73f0917", null ],
    [ "spa_pod_get_int", "group__spa__pod.html#ga0c2d7bbb354af62206cb8775a639988d", null ],
    [ "spa_pod_is_long", "group__spa__pod.html#ga17a44ecdb496ac51492a2031620a9653", null ],
    [ "spa_pod_get_long", "group__spa__pod.html#ga9382aceb62c82555c3e3223fa0da4d16", null ],
    [ "spa_pod_is_float", "group__spa__pod.html#gaee62f2962896bd0201a33586b40892f1", null ],
    [ "spa_pod_get_float", "group__spa__pod.html#ga6454e8f10d6a5b8d6d413b1b23134549", null ],
    [ "spa_pod_is_double", "group__spa__pod.html#gac52300de7f13278bfda13cc8d16d670a", null ],
    [ "spa_pod_get_double", "group__spa__pod.html#gaa2a0b63cc84967f45561da19d420182d", null ],
    [ "spa_pod_is_string", "group__spa__pod.html#ga96ef2d603e6d18b3b461c0f0ee785283", null ],
    [ "spa_pod_get_string", "group__spa__pod.html#ga9d5776b990a068561a318deec6accd74", null ],
    [ "spa_pod_copy_string", "group__spa__pod.html#ga675878397d60084917d134c5882ea7e2", null ],
    [ "spa_pod_is_bytes", "group__spa__pod.html#ga1f1a0ba4321b3b36374ec01dcb9f5278", null ],
    [ "spa_pod_get_bytes", "group__spa__pod.html#gaf862c079e6d7412d1b9891ef17e4805f", null ],
    [ "spa_pod_is_pointer", "group__spa__pod.html#ga54fd83598ec4391b5fcaa035a669874b", null ],
    [ "spa_pod_get_pointer", "group__spa__pod.html#ga2a5fc72e003fbde4fdf58a4877aee59c", null ],
    [ "spa_pod_is_fd", "group__spa__pod.html#ga4af52f5f7810c61ad0b31baa8ab89632", null ],
    [ "spa_pod_get_fd", "group__spa__pod.html#ga86cb2bcc11e2f431ba87fcdab9f5f58b", null ],
    [ "spa_pod_is_rectangle", "group__spa__pod.html#ga4ab6c61f2f16d5e5ab316db436f4e6d8", null ],
    [ "spa_pod_get_rectangle", "group__spa__pod.html#ga82aaa527c390ad8839f4aa165975b307", null ],
    [ "spa_pod_is_fraction", "group__spa__pod.html#gae4c5c97fe49fbdf5904f2763069ba3b4", null ],
    [ "spa_pod_get_fraction", "group__spa__pod.html#ga3644f6f4720c7e2ee8eec3b7c22f9055", null ],
    [ "spa_pod_is_bitmap", "group__spa__pod.html#ga01377325809bfef64781d29cd43d562a", null ],
    [ "spa_pod_is_array", "group__spa__pod.html#gabdf4cf3b06db29337cd7afdcaa29ddba", null ],
    [ "spa_pod_get_array", "group__spa__pod.html#ga9cd96f7179e7edcbb4a2385ce48229ad", null ],
    [ "spa_pod_copy_array", "group__spa__pod.html#ga694313e53324282f1e5c0c0abfeaee41", null ],
    [ "spa_pod_is_choice", "group__spa__pod.html#ga9c600d17cc240567be847b7f5f586bee", null ],
    [ "spa_pod_get_values", "group__spa__pod.html#gaa0eed1dfbff49bca1369a5c5f31fad39", null ],
    [ "spa_pod_is_struct", "group__spa__pod.html#ga881cb54fc6b73cc389ce7f43e84ecd26", null ],
    [ "spa_pod_is_object", "group__spa__pod.html#ga81a0efc821fbd7906e1a7f3f9938533c", null ],
    [ "spa_pod_is_object_type", "group__spa__pod.html#gabb298d1495a20cfdcf4f1f38e96fca5b", null ],
    [ "spa_pod_is_object_id", "group__spa__pod.html#ga61b9eca25d1e870703142d964719fb59", null ],
    [ "spa_pod_is_sequence", "group__spa__pod.html#ga8c99149486077bb1c281701b8fab1a7f", null ],
    [ "spa_pod_object_find_prop", "group__spa__pod.html#ga244df75ff8c63b2074bc803df3285de6", null ],
    [ "spa_pod_find_prop", "group__spa__pod.html#ga3b2c9003007b7ea6b84dfa486c37c9bd", null ],
    [ "spa_pod_object_fixate", "group__spa__pod.html#ga77978a8da43cf2f3bc74c086b046ceb0", null ],
    [ "spa_pod_fixate", "group__spa__pod.html#ga21c7b271eda2c6af65f613f26a95e941", null ],
    [ "spa_pod_object_is_fixated", "group__spa__pod.html#gae055e56cab8d9ce9a6144874cbdbc606", null ],
    [ "spa_pod_is_fixated", "group__spa__pod.html#ga97c73044f717933b8df8f254288d9c1d", null ],
    [ "spa_pod_parser_init", "group__spa__pod.html#ga9744b7a63e4be07f5a3da1428066c4c4", null ],
    [ "spa_pod_parser_pod", "group__spa__pod.html#ga0b94ddcb6ab81c4f5e452a6377393798", null ],
    [ "spa_pod_parser_get_state", "group__spa__pod.html#ga78e4ab314854074b4dd30344de63077b", null ],
    [ "spa_pod_parser_reset", "group__spa__pod.html#gad40a539793b9fcb49ce5993002db8241", null ],
    [ "spa_pod_parser_deref", "group__spa__pod.html#ga79e08a86ad91ae0e0898a7b3041fa33a", null ],
    [ "spa_pod_parser_frame", "group__spa__pod.html#gab5f325e540bbe89f7afbc86c4ff39dbd", null ],
    [ "spa_pod_parser_push", "group__spa__pod.html#ga96e7e55b25c16bec37945b6e960a2d17", null ],
    [ "spa_pod_parser_current", "group__spa__pod.html#ga4257244263c5cecd126992569265525c", null ],
    [ "spa_pod_parser_advance", "group__spa__pod.html#ga95a24dd82b1909c1438b811c41019e30", null ],
    [ "spa_pod_parser_next", "group__spa__pod.html#ga8fe7f96447b154a8b0d3de31dba55adc", null ],
    [ "spa_pod_parser_pop", "group__spa__pod.html#gaec011820be5aaf92c14634e5a7d0d8fa", null ],
    [ "spa_pod_parser_get_bool", "group__spa__pod.html#ga9871a0a457f1c1b6c88bb4fabe2a59e8", null ],
    [ "spa_pod_parser_get_id", "group__spa__pod.html#gabdf6e06a4b3861a11841166dff9d04c3", null ],
    [ "spa_pod_parser_get_int", "group__spa__pod.html#ga65b0bc2f897e44a0f2685ac5b498b9e1", null ],
    [ "spa_pod_parser_get_long", "group__spa__pod.html#ga5d25e015d753f88a4e272a4d007ec7fd", null ],
    [ "spa_pod_parser_get_float", "group__spa__pod.html#ga20146fdbbe61b2f25c42aa651874c0c5", null ],
    [ "spa_pod_parser_get_double", "group__spa__pod.html#ga0effbdc0cb617d12faafae6956e78344", null ],
    [ "spa_pod_parser_get_string", "group__spa__pod.html#ga7c658bc2f25b9a3271292df883a16cd7", null ],
    [ "spa_pod_parser_get_bytes", "group__spa__pod.html#ga2d6f05e6d04867d1635b2f49fe1e5924", null ],
    [ "spa_pod_parser_get_pointer", "group__spa__pod.html#gab23072b3f0f817478e011658b3504161", null ],
    [ "spa_pod_parser_get_fd", "group__spa__pod.html#gaa7ef713efb4ce6e7a49b4f3dcb9ba921", null ],
    [ "spa_pod_parser_get_rectangle", "group__spa__pod.html#ga7fda864b19555161ffa6b0bce9045fa8", null ],
    [ "spa_pod_parser_get_fraction", "group__spa__pod.html#gaeb21751483ea18549318af4ef7375274", null ],
    [ "spa_pod_parser_get_pod", "group__spa__pod.html#ga68d0832191b6f79f549735027d824632", null ],
    [ "spa_pod_parser_push_struct", "group__spa__pod.html#ga72967636bbc40a10041c9b78537fdfb3", null ],
    [ "spa_pod_parser_push_object", "group__spa__pod.html#ga80c5ed3cda1e515557a76c920fcb47fe", null ],
    [ "spa_pod_parser_can_collect", "group__spa__pod.html#gadc0c645fe393cbf90e92893207b356bf", null ],
    [ "spa_pod_parser_getv", "group__spa__pod.html#gabd77500f3d51263793922aa4144b69a2", null ],
    [ "spa_pod_parser_get", "group__spa__pod.html#ga3fee24722968e95e0452012d0496c351", null ]
];